@@ -4,17 +4,26 @@ import json
 import logging
 import configparser
 import boto3
+import sys
 
 from pathlib import Path
 from enum import Enum
+from . import ROOT_DIR
+
+logging.basicConfig(stream=sys.stdout, level=os.environ.get('LOGLEVEL', 'INFO').upper())
+
+logging.getLogger('boto3').setLevel(logging.CRITICAL)
+logging.getLogger('botocore').setLevel(logging.CRITICAL)
+logging.getLogger('s3transfer').setLevel(logging.CRITICAL)
+logging.getLogger('urllib3').setLevel(logging.CRITICAL)
 
 logger = logging.getLogger(__name__)
 
-CREATE_ACCOUNT_URL = "https://tksmt2n35c.execute-api.eu-west-1.amazonaws.com/accounts/create"
-LOGIN_URL = "https://tksmt2n35c.execute-api.eu-west-1.amazonaws.com/accounts/login"
-PROVISION_URL = "https://dev.aeroplatform.co.uk/compute/config"
-PROFILE_NAME = "aero"
-CLIENT_ID = "7qkl0rnt99f5nak775q1v99uv8"
+json_config = json.load(open(os.path.join(ROOT_DIR, "config.json"), "r"))
+
+BASE_URL = json_config['BASE_API_URL']
+CLIENT_ID = json_config['USER_POOL_CLIENT_ID']
+PROVISION_URL = f"{BASE_URL}/compute/config"
 
 class ComputeStatus():
 
@@ -62,8 +71,6 @@ class Account():
             self.login()
 
         response_data['config']['AERO_ID_TOKEN'] = self.id_token
-        response_data['config']['AERO_IDENTITY_POOL'] = "eu-west-1:d9b38264-d2de-44cc-8812-7e48943f31ab"
-        response_data['config']['AERO_PROVIDER'] = "cognito-idp.eu-west-1.amazonaws.com/eu-west-1_3E4bxVVbg"
 
         # Create Metaflow directory
         if not os.path.exists(f"{self.user_home}/.metaflowconfig"):
@@ -114,6 +121,7 @@ class Account():
             },
             ClientId=CLIENT_ID
         )
+        logger.debug(response)
 
         if 'AuthenticationResult' not in response:
             raise Exception("Error logging in")
