@@ -3,10 +3,17 @@ import time
 import os
 import logging
 import sys
+
+from .version import __version__
 from .account import Account, ComputeStatus
 
 logging.basicConfig(stream=sys.stdout, level=os.environ.get('LOGLEVEL', 'INFO').upper())
 
+logging.getLogger('boto3').setLevel(logging.CRITICAL)
+logging.getLogger('botocore').setLevel(logging.CRITICAL)
+logging.getLogger('s3transfer').setLevel(logging.CRITICAL)
+logging.getLogger('urllib3').setLevel(logging.CRITICAL)
+
 logger = logging.getLogger(__name__)
 
 site_base = "https://site.aeroplatform.co.uk"
@@ -27,6 +34,10 @@ def red(string):
 
 @click.group()
 def cli():
+    echo(f'{magenta(name_upper + " Platform")} {magenta("v" + __version__)}')
+    echo("A Data Platform designed to put developers first.")
+    echo(f"For more information, visit {cyan(site_base)}")
+    echo("")
     pass
 
 @cli.group(help="Account management")
@@ -39,9 +50,6 @@ def account():
 @click.option("--password", default=None,
     help="Password")
 def login(password, email):
-    echo(f'{magenta(name_upper + " Platform")} running under Python {sys.version}.')
-    echo("A Data Platform designed to put developers first.")
-    echo("")
 
     if not email and not password:
         email = click.prompt("Email > ")
@@ -51,6 +59,7 @@ def login(password, email):
         account = Account(email, password)
         _login(account)
     except Exception as e:
+        raise e
         echo("An error occured when attempting to log in, please try again")
         logger.debug(e)
         return
@@ -111,7 +120,7 @@ def _provision(account):
 
         if status == ComputeStatus.CREATED:
             echo(f"Compute Environment Created")
-            echo(f"You are now ready to run Flows with Aero. For more, read here: {site_base}")
+            echo(f"You are now ready to run Flows with Aero. For some basic tutorials, visit: {site_base}/commands")
             break  
 
         time.sleep(30)
